#!/bin/bash
# packager           : Frederic Boulet <bipbip> bipbiponlinux~AT~gmail.com
# Former Maintainer  : Jason Lin (infwonder)
# Former Maintainer  : Johannes Marbach (hennes)
# Former Maintainer  : Teran McKinney (sega01)
# homepage           : http://www.winehq.org/
# source location    :
# http://downloads.sourceforge.net/project/wine/Source/wine-1.5.0.tar.bz2
# last revised       : 18.3.2012
# dep                : 

softname='wine'
softversion='1.5.0'
packageversion='72.1'

arch='i486'
cpu='i686'

# log ;)
(

# parameters needed for the build process
buildir=$(pwd)
srcpkg="$buildir/$softname-$softversion.tar.bz2"
src="$buildir/$softname-$softversion"
package="$softname-$softversion-$arch-$packageversion"
dest="$buildir/$package"
source=http://downloads.sourceforge.net/project/wine/Source/$softname-$softversion.tar.bz2

# prepare the build result directory
dest="$buildir/$package"
rm -rf $dest
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/usr/share/icons/hicolor/48x48/apps
mkdir -p $dest/usr/src/$softname-$softversion
mkdir -p $dest/usr/share/wine/gecko

# Slack-desc
cat <<EOF > $dest/install/slack-desc
    |-----handy-ruler------------------------------------------------------|
wine: wine - Windows API Compatibility Layer 
wine: 
wine: Think of Wine as a compatibility layer for running Windows programs.
wine: Wine does not require Microsoft Windows, as it is a completely free
wine: alternative implementation of the Windows API consisting of 100%
wine: non-Microsoft code, however Wine can optionally use native Windows
wine: DLLs if they are available. Wine provides both a development toolkit
wine: for porting Windows source code to Unix as well as a program loader,
wine: allowing many unmodified Windows programs to run on x86-based Unixes,
wine: including Linux, FreeBSD, Mac OS X, and Solaris.
wine: 
EOF

# check if source is present
if [ -f $softname-$softversion.tar.bz2 ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c --no-check-certificate $source
fi

# install gecko
# check if source is present
cd $buildir
if [ -f wine_gecko-1.0.0-x86.cab ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c --no-check-certificate wget http://downloads.sourceforge.net/sourceforge/wine/wine_gecko-1.0.0-x86.cab
fi

#cp wine_gecko-1.0.0-x86.cab $dest/usr/share/wine/gecko/

# extract the source code
cd $buildir
tar xvf $srcpkg
cd $src

# build
export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"
 
# These additional CFLAGS solve FS#27662
export CFLAGS="${CFLAGS/-D_FORTIFY_SOURCE=2/} -D_FORTIFY_SOURCE=0"
export CXXFLAGS="${CFLAGS/-D_FORTIFY_SOURCE=2/} -D_FORTIFY_SOURCE=0" 
  
./configure \
	--prefix=/usr \
	--localstatedir=/var \
	--sysconfdir=/etc \
	--mandir=/usr/man \
	--infodir="/usr/info" \
	--enable-static="no" \
	--enable-shared="yes" \
	--build=$arch-slackware-linux || exit

make depend || return 1
# These additional CFLAGS solve FS#27560
make CFLAGS+="-mstackrealign" CXXFLAGS+="-mstackrealign" || return 1
make install DESTDIR=$dest

# make icon
cp -v $buildir/${softname}cfg.png $dest/usr/share/icons/hicolor/48x48/apps

# make desktop file
rm -v $dest/usr/share/applications/*
cp -v $buildir/$softname.desktop $dest/usr/share/applications
cp -v $buildir/winecfg.desktop $dest/usr/share/applications

# add 'default' files
cd $src
mkdir -p $dest/usr/doc/$softname-$softversion
cp -a \
   ANNOUCE COPYING.LIB AUTHORS LICENSE README VERSION ChangeLog\
   $dest/usr/doc/$softname-$softversion
cp -v $src/documentation/* $dest/usr/doc/$softname-$softversion/
        
# strip executables
( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

# compress man pages
( cd $dest/usr/man
  find . -name "*.?" | xargs gzip -9
)

# ZenBuild
cp $buildir/build-$softname.sh $dest/usr/src/$softname-$softversion

# set target permissions
chown -R root:root $dest

cd $dest
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# real packaging work:
cd $dest
makepkg -l y -c n $dest.txz

# computes the md5sum signature for the package
cd $buildir
md5sum $package.txz > $package.md5

# .dep
cd $buildir
echo -e "alsa-lib,audiofile,cxxlibs|gcc-g++,cyrus-sasl,e2fsprogs,\
esound,gcc,krb5,lcms,libICE,libSM,libX11,libXau,libXdamage,libXdmcp,\
libXext,libXfixes,libXxf86vm,libdrm,libexif,libgphoto2,libtool,libxcb,\
libxml2,mesa,openldap-client,openssl,zlib" > $package.dep

# src file
echo http://zenwalk.pinguix.com/user-accounts/bip/EXTRA/xap/wine/source/build-wine.sh > $package.src
echo $source >> $package.src

# erase
rm -rf $src
rm -rf $dest

# log ;)
) 2>&1 | tee "$softname-$softversion-build.log"
